#
# spec file for package maliit-keyboard
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude qmlimport\\((MaliitKeyboard|keys)
Name:           maliit-keyboard
Version:        2.3.1
Release:        3.3
License:        BSD-3-Clause AND LGPL-3.0-only AND CC-BY-3.0
Summary:        Maliit virtual keyboard
URL:            https://github.com/maliit/keyboard
Source0:        keyboard-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libpresage-devel
BuildRequires:  presage
BuildRequires:  sqlite3
BuildRequires:  cmake(MaliitPlugins)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  pkgconfig(anthy)
BuildRequires:  pkgconfig(chewing)
BuildRequires:  pkgconfig(hunspell)
BuildRequires:  pkgconfig(libpinyin)
Requires:       libqt5-qtwayland
Recommends:     %{name}-layouts
Recommends:     %{name}-styles-ubuntu
Recommends:     %{name}-themes
Suggests:       dejavu-fonts
Obsoletes:      maliit-keyboard2 < %{version}
Provides:       maliit-keyboard2 = %{version}
Obsoletes:      maliit-keyboard-emoji < %{version}
Provides:       maliit-keyboard-emoji = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Maliit provides a flexible and cross-platform input method framework.
It has a plugin-based client-server architecture where applications
act as clients and communicate with the Maliit server via input
context plugins. The communication link currently uses D-Bus. Maliit
is an open source framework (LGPL 2) with open source plugins (BSD).

%package        layouts
Summary:        Maliit Keyboard Layout Files
Requires:       %{name} = %{version}

%description    layouts
Provides layouts that are not english QWERTY
for Maliit Virtual Keyboard.

%lang_package

%prep
%autosetup -p1 -n keyboard-%{version}

%build
%cmake -Denable-presage=ON -Denable-hunspell=ON -Denable-tests=OFF
%cmake_build

%install
%cmake_install
%{__rm} -rf %{buildroot}%{_datadir}/doc/%{name}
%fdupes %{buildroot}%{_prefix}

%find_lang %{name} --with-qt

%check
%ctest

%files layouts
%{_libdir}/maliit/keyboard2/languages/
%exclude %{_libdir}/maliit/keyboard2/languages/en/
%dnl %{_datadir}/locale/*

%files
%defattr(-,root,root,-)
%license COPYING.BSD COPYING
%{_bindir}/%{name}
%dir %{_libdir}/maliit/keyboard2
%{_libdir}/maliit/keyboard2/qml/
%{_libdir}/maliit/keyboard2/languages/en/
%dir %{_datadir}/maliit
%dir %{_datadir}/maliit/keyboard2
%{_datadir}/maliit/keyboard2/{devices,icons,images}/
%dir %{_libdir}/maliit/
%{_libdir}/maliit/plugins/
%{_datadir}/glib-2.0/schemas/org.maliit.keyboard.maliit.gschema.xml
%{_datadir}/applications/com.github.maliit.keyboard.desktop
%{_datadir}/metainfo/*.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Thu Jul  4 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Fix build without checks (boo#1227364)
* Thu Jun 27 2024 Shawn Dunn <sfalken@opensuse.org>
- Added %%check section
- Added explicit Requires: on libqt5-qtwayland (boo#1222993)
* Sun Mar 17 2024 Shawn Dunn <sfalken@opensuse.org>
- Split -layouts and -lang subpackages to better conform with
  Factory packaging policy
* Fri Mar 15 2024 Shawn Dunn <sfalken@opensuse.org>
- Moved from OBS package maliit-keyboard2, for :Factory submission
  the Project packagename needs to match %%{name}
* Thu Mar 14 2024 Shawn Dunn <sfalken@opensuse.org>
- Removed BuildRequires: cmake(Qt5Feedback)
  * Causes Buildfailure
* Sat May 27 2023 Adrian Campos Garrido <adriancampos@teachelp.com>
- Update to version 2.3.1
* Tue Feb 15 2022 Andrés B.S. <andresbs@opensuse.org>
- Changes for the version 2.2.0:
  * Revert to simpler method of word engine plugin loading
  * Improved layout switching behavior to cycle through all enabled
    languages.
  * Handle invalid values being set for active and enabled
    languages.
  * Remove previous-language setting
  * Support for disabling keyboard hide and unhide animations
  * Integrate emoji layout into main keyboard
  * Fix the default hunspell dictionary path
  * Fix Qt and glib deprecation warnings during compilation
  * Add ẞ and missing currency symbols to German keyboard
  * Fix build with hunspell disabled
  * Synchronize changes from Lomiri keyboard fork
  * Selection mode available when in cursor mode now
  * Toolbar in cursor mode for undo/redo/select all and
    cut/copy/paste.
  * Belarusian layout
  * Bulgarian layout
  * English (Dvorak) layout
  * French (Swiss) layout
  * Lithuanian layout
  * Macedonian layout
  * Thai layout
  * Turkish layout
  * Fix compilation with presage enabled on c++17 default
    compilers.
  * Enable translations support
  * Set haptic feedback duration to 100ms and intensity to 0.5
  * Add haptic feedback to spacebar
  * Use the correct kcm name for settings in Plasma Mobile
* Tue Nov  2 2021 Andrés B.S. <andresbs@opensuse.org>
- Revert package name from maliit-keyboard2 to maliit-keyboard.
* Wed Sep 22 2021 Andrés B.S. <andresbs@opensuse.org>
- Changes for the version 2.1.0:
  * Remove label from language key on emoji keyboard
  * Remove the unused and outdated styling support
  * Support icon themes to load the icons
  * Make sure Settings also work when running on Plasma
  * left/right arrow keypress: Don't check for surrounding text
  * Bypass argument count problem for newPredictionSuggestions and
    newSpellingSuggestions
  * Clean up unused code
  * Let language features customize primary candidate index
  * Recalculate primary candidates after refreshing candidate list
  * Process pinyin sequence properly
  * Handle partial candidate words in pinyin properly
  * Allow force refreshing candidate list
  * Allow delaying committing text when a candidate word is
    selected
  * Provide appstream information
  * Use Q_ENUM
  * Optimise symbols for Simplified Chinese
  * Use only valid pinyin symbols on pinyin keyboard
  * Fix incorrect key name in tablet.json
  * Don't crash when no language plugin is loaded
  * Drop the Ubuntu styling subpackage
* Fri Jun 25 2021 Antonio Larrosa <alarrosa@suse.com>
- Recommend instead of Suggesting %%{name}-emoji and
  %%{name}-styles-ubuntu. If -emoji is not installed and the user
  changes to the emoji keyboard, it seems to be impossible to
  change back to the normal keyboard (unless the configuration
  files are changed manually). We probably should consider even
  Requiring them, but probably Recommending is good enough.
- Don't require the exact same release of the main package from
  subpackages, a matching version number is enough.
* Fri Apr  2 2021 Andrés B.S. <andresbs@opensuse.org>
- Update to version 2.0, no changelog is provided. This solves
  bsc#1184014.
* Thu Feb 11 2021 Andrés B.S. <andresbs@opensuse.org>
- "First" buid.
